Welcome to Inference of Compartmental Models Toolbox's documentation!
=====================================================================


.. toctree::
   :maxdepth: 2
   :caption: Contents:


   Introduction <readme>
   installation
   Getting started <example>
   api/references
   contributing

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
